@@ -18,8 +18,9 @@
 #' @importFrom stringr str_count
 #'
 #' @examples
-#'
-#' \dontshow{.old_wd <- setwd(tempdir())}
+#' \dontshow{
+#' .old_wd <- setwd(tempdir())
+#' }
 #'
 #' seq_file_ops(n = 10, target_dir = "munge")
 #'
@@ -32,26 +33,32 @@
 #' unlink("munge", recursive = TRUE)
 #' unlink("complex_vector", recursive = TRUE)
 #'
-#' \dontshow{setwd(.old_wd)}
+#' \dontshow{
+#' setwd(.old_wd)
+#' }
 #'
 #' @export
 seq_file_ops <- function(n, target_dir = NULL, filetype = "R",
-                              force = FALSE){
-  if(!file.exists(target_dir)){
+                         force = FALSE) {
+  # handle input params -----------------------------------------------------
+
+  if (!file.exists(target_dir)) {
     # if the directory doesn't exist, create it with a prompt.
     dir.create(target_dir)
-    message(paste("seq_file_ops() created",
-                paste0(target_dir, "/"), "as it was not found."))
+    message(paste(
+      "seq_file_ops() created",
+      paste0(target_dir, "/"), "as it was not found."
+    ))
   }
 
-  if(length(n) == 1){
+  # create file vector ------------------------------------------------------
+
+  if (length(n) == 1) {
     # if user specifies n as single digit, create required vector
     req_nos <- c(1:n)
-
-  } else if(length(n) > 1){
+  } else if (length(n) > 1) {
     # if user provides a vector for n, just use vector
     req_nos <- n
-
   }
 
   # wherever the digits are single, add a 0 in front
@@ -60,34 +67,38 @@ seq_file_ops <- function(n, target_dir = NULL, filetype = "R",
   )
 
   # create the filenames
-  req_files <- paste0(paste(target_dir, req_nos, sep = "/"),
-                      "-.",
-                      filetype)
+  req_files <- paste0(
+    paste(target_dir, req_nos, sep = "/"),
+    "-.",
+    filetype
+  )
 
-  if(force == FALSE){
-  # find any preexisting files
-  ex_files <-  req_files[file.exists(req_files)]
-  # only message warning if at least one existing file is found
-  if(length(ex_files) > 0){
-  # message message
-  message(paste("Following found files will not be overwritten:",
-                paste(ex_files, collapse = ", ")))
-  }
+  # write to file -----------------------------------------------------------
 
-  # write only new files
-  only_new <- req_files[!(req_files %in% ex_files)]
-  invisible(file.create(only_new))
-  # message conf msg
-  message(paste("New files created:", paste(only_new, collapse = ", ")))
+  if (force == FALSE) {
+    # find any preexisting files
+    ex_files <- req_files[file.exists(req_files)]
+    # only message warning if at least one existing file is found
+    if (length(ex_files) > 0) {
+      # message message
+      message(paste(
+        "Following found files will not be overwritten:",
+        paste(ex_files, collapse = ", ")
+      ))
+    }
 
-  } else{
+    # write only new files
+    only_new <- req_files[!(req_files %in% ex_files)]
+    invisible(file.create(only_new))
+    # message conf msg
+    message(paste("New files created:", paste(only_new, collapse = ", ")))
+  } else {
     # message conf msg
     warning(paste(
       "force = TRUE. Files may be overwritten. Following files created",
       paste(req_files, collapse = ", ")
-      ))
+    ))
     # write all files asked for
     invisible(file.create(req_files))
-
   }
 }
